@@ -190,6 +190,9 @@ public:
 	int y_tiles() const;
 
 	bool isPaused() const { return paused; }
+	void resetTimer();
+	void resetUndo();
+	void resetRedo();
 
 signals:
 	void markMatched();
