@@ -12,7 +12,8 @@
  *
  *******************************************************************
  *
- * created 1997 by Mario Weilguni <mweilguni@sime.com>
+ * Copyright (C) 1997 Mario Weilguni <mweilguni@sime.com>
+ * Copyright (C) 2002-2004 Dave Corrie  <kde@davecorrie.com>
  *
  *******************************************************************
  *
@@ -30,8 +31,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with KSHISEN; see the file COPYING.  If not, write to
- * the Free Software Foundation, 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  *******************************************************************
  */
@@ -40,30 +41,37 @@
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <kconfig.h>
+#include <klocale.h>
+#include <kglobal.h>
 
 #include "version.h"
 #include "app.h"
 
-static const char description[] = I18N_NOOP("A KDE game similiar to Mahjongg");
+static const char description[] = I18N_NOOP("A KDE game similar to Mahjongg");
+
+// A hack to circumvent tricky i18n issue, not used later on in the code.
+// Both context and contents must be exactly the same as for the entry in
+// kdelibs/kdeui/ui_standards.rc
+static const char dummy[] = I18N_NOOP2("Menu title", "&Move");
 
 int main(int argc, char **argv)
 {
-	KAboutData aboutData( "kshisen", I18N_NOOP("Shisen-Sho"),
-		KSHISEN_VERSION, description, KAboutData::License_GPL,
-		"(c) 1997, Mario Weilguni");
-	aboutData.addAuthor("Dave Corrie", I18N_NOOP("Current Maintainer"), "kde@davecorrie.com");
-	aboutData.addAuthor("Mario Weilguni", I18N_NOOP("Original Author"), "mweilguni@sime.com");
-	aboutData.addCredit("Jason Lane", I18N_NOOP("Added 'tiles removed' counter\nTile smooth-scaling and window resizing"), "jglane@btopenworld.com");
-	aboutData.addCredit(0, I18N_NOOP("Thanks also to everyone who should be listed here but isn't!"), 0);
+	KAboutData aboutData( "kshisen", 0, ki18n("Shisen-Sho"),
+		KSHISEN_VERSION, ki18n(description), KAboutData::License_GPL,
+		ki18n("(c) 1997, Mario Weilguni"), KLocalizedString(), "http://games.kde.org/kshisen" );
+	aboutData.addAuthor(ki18n("Dave Corrie"), ki18n("Current Maintainer"), "kde@davecorrie.com");
+	aboutData.addAuthor(ki18n("Mario Weilguni"), ki18n("Original Author"), "mweilguni@sime.com");
+	aboutData.addCredit(ki18n("Mauricio Piacentini"), ki18n("KMahjonggLib integration for KDE4"), "mauricio@tabuleiro.com");
+	aboutData.addCredit(ki18n("Jason Lane"), ki18n("Added 'tiles removed' counter\nTile smooth-scaling and window resizing"), "jglane@btopenworld.com");
+	aboutData.addCredit(ki18n("Thanks also to everyone who should be listed here but is not!"));
 	KCmdLineArgs::init( argc, argv, &aboutData );
 
 	KApplication a;
-	KGlobal::locale()->insertCatalogue("libkdegames");
+	KGlobal::locale()->insertCatalog("libkdegames");
+	KGlobal::locale()->insertCatalog("libkmahjongg");
 
 	App *app = new App();
 	app->show();
-	a.setMainWidget(app);
-	a.config()->sync();
-  return a.exec();
+	return a.exec();
 }
 
