@@ -1,15 +1,42 @@
-#include <qlabel.h>
-#include <qcombobox.h>
-#include <qtabwidget.h>
-#include <qslider.h>
-#include <qlcdnumber.h>
-#include <qlayout.h>
+/*
+    Copyright (C) 1998-2001 Andreas Zehender <az@azweb.de>
 
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+*/
+
+#include "dialogs.h"
+
+#include <QGridLayout>
+#include <QLCDNumber>
+#include <QSlider>
+
+#include <kcombobox.h>
 #include <klocale.h>
+#include <ktabwidget.h>
 
 #include "options.h"
-#include "dialogs.h"
-#include "general.h"
+#include "ui_general.h"
+
+class General : public QWidget, public Ui::General
+{
+public:
+    General(QWidget* parent=0)
+        : QWidget(parent)
+        {
+            setupUi(this);
+        }
+};
 
 bool operator!=(const SConfig &s1, const SConfig &s2)
 {
@@ -113,8 +140,8 @@ int ConfigSetup::Position[EditNum]=
 
 const int LCDLen=6;
 
-ConfigSetup::ConfigSetup(SConfig *custom,QWidget *parent,const char *name)
-      :QWidget( parent, name )
+ConfigSetup::ConfigSetup(SConfig *custom,QWidget *parent)
+      :QWidget( parent )
 {
    QLabel *label[EditNum];
    QGridLayout *stacklayout[TabNum];
@@ -130,32 +157,35 @@ ConfigSetup::ConfigSetup(SConfig *custom,QWidget *parent,const char *name)
    
    //box=new QGroupBox(i18n("Config"),this);
    //setMainWidget( box );
-   QVBoxLayout *boxlayout = new QVBoxLayout( this, 6 );
+   QVBoxLayout *boxlayout = new QVBoxLayout( this );
+   boxlayout->setMargin(6);
    
-   tabs=new QTabWidget(this);
+   tabs=new KTabWidget(this);
    for(i=0;i<TabNum;i++)
    {
       configWidgets[i]=new QWidget(tabs);
-      stacklayout[i]=new QGridLayout(configWidgets[i],6,3,10);
+      stacklayout[i]=new QGridLayout(configWidgets[i]);
+      stacklayout[i]->setMargin(10);
    }
    
    for(i=0;i<EditNum;i++)
    {
       label[i]=new QLabel(i18n(LabelName[i]),configWidgets[Parent[i]]);
-      slider[i]=new QSlider(EditVal[i][0]*EditDiv[i],EditVal[i][1]*EditDiv[i],
-                            (EditVal[i][1]-EditVal[i][0])/10,
-                            EditVal[i][2]*EditDiv[i],
-                            QSlider::Horizontal,configWidgets[Parent[i]]);
+      slider[i]=new QSlider(Qt::Horizontal,configWidgets[Parent[i]]);
+      slider[i]->setRange((int)(EditVal[i][0]*EditDiv[i]), (int)(EditVal[i][1]*EditDiv[i]));
+      slider[i]->setPageStep((int)((EditVal[i][1]-EditVal[i][0])/10));
+      slider[i]->setValue((int)(EditVal[i][2]*EditDiv[i]));
       connect(slider[i],SIGNAL(valueChanged(int)),SLOT(sliderChanged(int)));
       value[i]=new QLCDNumber(LCDLen,configWidgets[Parent[i]]);
       value[i]->setFrameStyle(QFrame::NoFrame);
    }
 
-   configCombo=new QComboBox(false,this);
+   configCombo=new KComboBox(this);
+   configCombo->setEditable(false);
    connect(configCombo,SIGNAL(activated(int)),SLOT(configSelected(int)));
    for(i=0;i<predefinedConfigNum;i++)
-      configCombo->insertItem(i18n(predefinedConfigName[i]));
-   configCombo->insertItem(i18n("Custom"));
+      configCombo->addItem(i18n(predefinedConfigName[i]));
+   configCombo->addItem(i18nc("custom values","Custom"));
 
    boxlayout->addSpacing( 2 * 6 );
    boxlayout->addWidget(configCombo);
@@ -171,12 +201,12 @@ ConfigSetup::ConfigSetup(SConfig *custom,QWidget *parent,const char *name)
    for(i=0;i<TabNum;i++)
       stacklayout[i]->activate();
 
-   tabs->addTab(configWidgets[0],i18n("General"));
+   tabs->addTab(configWidgets[0],i18nc("general game settings","General"));
    tabs->addTab(configWidgets[1],i18n("Bullet"));
-   tabs->addTab(configWidgets[2],i18n("Name","Mine"));
+   tabs->addTab(configWidgets[2],i18nc("Name","Mine"));
    tabs->addTab(configWidgets[3],i18n("Ship"));
-   tabs->addTab(configWidgets[4],i18n("Sun"));
-   tabs->addTab(configWidgets[5],i18n("Start"));
+   tabs->addTab(configWidgets[4],i18nc("the star, Sol","Sun"));
+   tabs->addTab(configWidgets[5],i18nc("initial position and velocities of players","Start"));
    tabs->addTab(configWidgets[6],i18n("Powerups"));
 
    customConfig=custom;
@@ -188,7 +218,7 @@ void ConfigSetup::updateWidgets()
 {
    config=*customConfig;
    selectedConfig = -1;
-   configCombo->setCurrentItem(Options::lastConfig());
+   configCombo->setCurrentIndex(Options::lastConfig());
    configSelected(Options::lastConfig());
 }
 
@@ -247,15 +277,15 @@ void ConfigSetup::updateSettings()
    *customConfig=config;
 
    Options::setLastConfig(selectedConfig);
-   Options::writeConfig();
+   Options::self()->writeConfig();
 }
 
 bool ConfigSetup::hasChanged()
 {
-   if (configCombo->currentItem() != Options::lastConfig())
+   if (configCombo->currentIndex() != Options::lastConfig())
       return true;
 
-   if (configCombo->currentItem() != predefinedConfigNum)
+   if (configCombo->currentIndex() != predefinedConfigNum)
       return false;
 
    return ((*customConfig) != config);
@@ -263,13 +293,13 @@ bool ConfigSetup::hasChanged()
 
 void ConfigSetup::updateWidgetsDefault()
 {
-   configCombo->setCurrentItem(0);
+   configCombo->setCurrentIndex(0);
    configSelected(0);
 }
 
 bool ConfigSetup::isDefault()
 {
-   return configCombo->currentItem() == 0;
+   return configCombo->currentIndex() == 0;
 }
 
 void ConfigSetup::configSelected(int num)
@@ -392,12 +422,12 @@ SettingsDialog::SettingsDialog(SConfig *customConfig, QWidget *parent, const cha
   : KConfigDialog( parent, name, Options::self())
 {
   General *general = new General();
-  addPage(general, i18n("General"), "package_settings", i18n("General Settings"));
+  addPage(general, i18nc("general settings","General"), "games-config-options", i18n("General Settings"));
 
   cs = new ConfigSetup(customConfig);
-  addPage(cs, i18n("Game"), "kspaceduel", i18n("Game Settings"));
+  addPage(cs, i18nc("game settings","Game"), "games-config-custom", i18n("Game Settings"));
   connect(cs, SIGNAL(changed()), this, SLOT(updateButtons()));
- 
+  setHelp(QString(),"kspaceduel");
 //  resize(600,400);
 }
 
